/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Confluent Community License (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of the
 * License at
 *
 * http://www.confluent.io/confluent-community-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

package io.confluent.kafka.secretregistry.storage;

import java.util.Objects;

public class UriInfo {
  private final String scheme;
  private final String host;
  private final int port;

  public UriInfo(String scheme, String host, int port) {
    this.scheme = scheme;
    this.host = host;
    this.port = port;
  }

  public String scheme() {
    return scheme;
  }

  public String host() {
    return host;
  }

  public int port() {
    return port;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    UriInfo uriInfo = (UriInfo) o;
    return port == uriInfo.port
        && Objects.equals(scheme, uriInfo.scheme)
        && Objects.equals(host, uriInfo.host);
  }

  @Override
  public int hashCode() {
    return Objects.hash(scheme, host, port);
  }

  @Override
  public String toString() {
    return scheme + "://" + host + ":" + port;
  }
}
